==> haskell-logict-0.7.0.3-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.0.3
visibility:           public
id:                   logict-0.7.0.3-KZUe9tzvjVcClKtKMrPDgZ
key:                  logict-0.7.0.3-KZUe9tzvjVcClKtKMrPDgZ
license:              BSD-3-Clause
copyright:
    Copyright (c) 2007-2014, Dan Doel,
    Copyright (c) 2011-2013, Edward Kmett,
    Copyright (c) 2014, Roman Cheplyaka

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>

category:             Control
abi:                  8d170a1ab599a5d3ea8fdbe4cd4b145f
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-8.10.3/site-local/logict-0.7.0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/logict-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/logict-0.7.0.3
hs-libraries:         HSlogict-0.7.0.3-KZUe9tzvjVcClKtKMrPDgZ
depends:              base-4.14.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.7.0.3-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.0.3
visibility:           public
id:                   logict-0.7.0.3-G3psSzCQl1eHC4bgUVizZj
key:                  logict-0.7.0.3-G3psSzCQl1eHC4bgUVizZj
license:              BSD-3-Clause
copyright:
    Copyright (c) 2007-2014, Dan Doel,
    Copyright (c) 2011-2013, Edward Kmett,
    Copyright (c) 2014, Roman Cheplyaka

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    A continuation-based, backtracking, logic programming monad.
    An adaptation of the two-continuation implementation found
    in the paper "Backtracking, Interleaving, and Terminating
    Monad Transformers" available here:
    <http://okmij.org/ftp/papers/LogicT.pdf>

category:             Control
abi:                  f7067657de716ef676ad3fbea4de92a6
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-8.10.3/site-local/logict-0.7.0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/logict-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/logict-0.7.0.3
hs-libraries:         HSlogict-0.7.0.3-G3psSzCQl1eHC4bgUVizZj
depends:              base-4.14.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
